Class: Aws::MarketplaceMetering::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceMetering::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplacemetering/client.rb
Overview
An API client for MarketplaceMetering. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceMetering::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_meter_usage(params = {}) ⇒ Types::BatchMeterUsageResult
Amazon Web Services Marketplace is introducing Concurrent Agreements, enabling buyers to make multiple purchases per Amazon Web Services account.
-
#meter_usage(params = {}) ⇒ Types::MeterUsageResult
As a seller, your software hosted in the buyer’s Amazon Web Services account uses this API action to emit metering records directly to Amazon Web Services Marketplace.
-
#register_usage(params = {}) ⇒ Types::RegisterUsageResult
Paid container software products sold through Amazon Web Services Marketplace must integrate with the Amazon Web Services Marketplace Metering Service and call the ‘RegisterUsage` operation for software entitlement and metering.
-
#resolve_customer(params = {}) ⇒ Types::ResolveCustomerResult
‘ResolveCustomer` is called by a SaaS application during the registration process.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
958 959 960 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 958 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
961 962 963 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 961 def errors_module Errors end |
Instance Method Details
#batch_meter_usage(params = {}) ⇒ Types::BatchMeterUsageResult
Amazon Web Services Marketplace is introducing Concurrent Agreements, enabling buyers to make multiple purchases per Amazon Web Services account. Starting June 1, 2026, new SaaS products must use ‘CustomerAWSAccountId` (instead of `CustomerIdentifier`), `LicenseArn` (instead of `ProductCode`) to support this feature. Existing integrations will continue to work. Review the new integration for Concurrent Agreements [here].
To post metering records for customers, SaaS applications call ‘BatchMeterUsage`, which is used for metering SaaS flexible consumption pricing (FCP). Identical requests are idempotent and can be retried with the same records or a subset of records. Each `BatchMeterUsage` request is for only one product. If you want to meter usage for multiple products, you must make multiple `BatchMeterUsage` calls.
Usage records should be submitted in quick succession following a recorded event. Usage records aren’t accepted 6 hours or more after an event.
‘BatchMeterUsage` can process up to 25 `UsageRecords` at a time, and each request must be less than 1 MB in size. Optionally, you can have multiple usage allocations for usage data that’s split into buckets according to predefined tags.
‘BatchMeterUsage` returns a list of `UsageRecordResult` objects, which have each `UsageRecord`. It also returns a list of `UnprocessedRecords`, which indicate errors on the service side that should be retried.
For Amazon Web Services Regions that support ‘BatchMeterUsage`, see [BatchMeterUsage Region support].
<note markdown=“1”> For an example of ‘BatchMeterUsage`, see [ BatchMeterUsage code example] in the *Amazon Web Services Marketplace Seller Guide*.
</note>
[1]: catalog.workshops.aws/mpseller/en-US/saas/integration-for-concurrent-agreements [2]: docs.aws.amazon.com/marketplace/latest/APIReference/metering-regions.html#batchmeterusage-region-support [3]: docs.aws.amazon.com/marketplace/latest/userguide/saas-code-examples.html#saas-batchmeterusage-example
604 605 606 607 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 604 def batch_meter_usage(params = {}, = {}) req = build_request(:batch_meter_usage, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 931 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceMetering') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplacemetering' context[:gem_version] = '1.93.0' Seahorse::Client::Request.new(handlers, context) end |
#meter_usage(params = {}) ⇒ Types::MeterUsageResult
As a seller, your software hosted in the buyer’s Amazon Web Services account uses this API action to emit metering records directly to Amazon Web Services Marketplace. You must use the following buyer Amazon Web Services account credentials to sign the API request.
-
For **Amazon EC2** deployments, your software must use the [IAM role for Amazon EC2] to sign the API call for ‘MeterUsage` API operation.
-
For **Amazon EKS** deployments, your software must use [IAM roles for service accounts (IRSA)] to sign the API call for the ‘MeterUsage` API operation. Using [EKS Pod Identity], the node role, or long-term access keys is not supported.
-
For **Amazon ECS** deployments, your software must use [Amazon ECS task IAM] role to sign the API call for the ‘MeterUsage` API operation. Using the node role or long-term access keys are not supported.
-
For **Amazon Bedrock AgentCore Runtime** deployments, your software must use the [AgentCore Runtime execution role] to sign the API call for the ‘MeterUsage` API operation. Long-term access keys are not supported.
The handling of ‘MeterUsage` requests varies between Amazon Bedrock AgentCore Runtime and non-Amazon Bedrock AgentCore deployments.
-
For **non-Amazon Bedrock AgentCore Runtime** deployments, you can only report usage once per hour for each dimension. For AMI-based products, this is per dimension and per EC2 instance. For container products, this is per dimension and per ECS task or EKS pod. You can’t modify values after they’re recorded. If you report usage before a current hour ends, you will be unable to report additional usage until the next hour begins. The ‘Timestamp` request parameter is rounded down to the hour and used to enforce this once-per-hour rule for idempotency. For requests that are identical after the `Timestamp` is rounded down, the API is idempotent and returns the metering record ID.
-
For **Amazon Bedrock AgentCore Runtime** deployments, you can report usage multiple times per hour for the same dimension. You do not need to aggregate metering records by the hour. You must include an idempotency token in the ‘ClientToken` request parameter. If using an Amazon SDK or the Amazon Web Services CLI, you must use the latest version which automatically includes an idempotency token in the `ClientToken` request parameter so that the request is processed successfully. The `Timestamp` request parameter is not rounded down to the hour and is not used for duplicate validation. Requests with duplicate `Timestamps` are aggregated as long as the `ClientToken` is unique.
If you submit records more than six hours after events occur, the records won’t be accepted. The timestamp in your request determines when an event is recorded.
You can optionally include multiple usage allocations, to provide customers with usage data split into buckets by tags that you define or allow the customer to define.
For Amazon Web Services Regions that support ‘MeterUsage`, see
- MeterUsage Region support for Amazon EC2][6
-
and [MeterUsage Region
support for Amazon ECS and Amazon EKS].
[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-roles-for-amazon-ec2.html [2]: docs.aws.amazon.com/eks/latest/userguide/iam-roles-for-service-accounts.html [3]: docs.aws.amazon.com/eks/latest/userguide/pod-identities.html [4]: docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html [5]: docs.aws.amazon.com/bedrock-agentcore/latest/devguide/runtime-permissions.html#runtime-permissions-execution [6]: docs.aws.amazon.com/marketplace/latest/APIReference/metering-regions.html#meterusage-region-support-ec2 [7]: docs.aws.amazon.com/marketplace/latest/APIReference/metering-regions.html#meterusage-region-support-ecs-eks
768 769 770 771 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 768 def meter_usage(params = {}, = {}) req = build_request(:meter_usage, params) req.send_request() end |
#register_usage(params = {}) ⇒ Types::RegisterUsageResult
Paid container software products sold through Amazon Web Services Marketplace must integrate with the Amazon Web Services Marketplace Metering Service and call the ‘RegisterUsage` operation for software entitlement and metering. Free and BYOL products for Amazon ECS or Amazon EKS aren’t required to call ‘RegisterUsage`, but you may choose to do so if you would like to receive usage data in your seller reports. The sections below explain the behavior of `RegisterUsage`. `RegisterUsage` performs two primary functions: metering and entitlement.
-
Entitlement: ‘RegisterUsage` allows you to verify that the customer running your paid software is subscribed to your product on Amazon Web Services Marketplace, enabling you to guard against unauthorized use. Your container image that integrates with `RegisterUsage` is only required to guard against unauthorized use at container startup, as such a `CustomerNotSubscribedException` or `PlatformNotSupportedException` will only be thrown on the initial call to `RegisterUsage`. Subsequent calls from the same Amazon ECS task instance (e.g. task-id) or Amazon EKS pod will not throw a `CustomerNotSubscribedException`, even if the customer unsubscribes while the Amazon ECS task or Amazon EKS pod is still running.
-
Metering: ‘RegisterUsage` meters software use per ECS task, per hour, or per pod for Amazon EKS with usage prorated to the second. A minimum of 1 minute of usage applies to tasks that are short lived. For example, if a customer has a 10 node Amazon ECS or Amazon EKS cluster and a service configured as a Daemon Set, then Amazon ECS or Amazon EKS will launch a task on all 10 cluster nodes and the customer will be charged for 10 tasks. Software metering is handled by the Amazon Web Services Marketplace metering control plane—your software is not required to perform metering-specific actions other than to call `RegisterUsage` to commence metering. The Amazon Web Services Marketplace metering control plane will also bill customers for running ECS tasks and Amazon EKS pods, regardless of the customer’s subscription state, which removes the need for your software to run entitlement checks at runtime. For containers, ‘RegisterUsage` should be called immediately at launch. If you don’t register the container within the first 6 hours of the launch, Amazon Web Services Marketplace Metering Service doesn’t provide any metering guarantees for previous months. Metering will continue, however, for the current month forward until the container ends. `RegisterUsage` is for metering paid hourly container products.
For Amazon Web Services Regions that support ‘RegisterUsage`, see [RegisterUsage Region support].
857 858 859 860 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 857 def register_usage(params = {}, = {}) req = build_request(:register_usage, params) req.send_request() end |
#resolve_customer(params = {}) ⇒ Types::ResolveCustomerResult
‘ResolveCustomer` is called by a SaaS application during the registration process. When a buyer visits your website during the registration process, the buyer submits a registration token through their browser. The registration token is resolved through this API to obtain a `CustomerIdentifier` along with the `CustomerAWSAccountId`, `ProductCode`, and `LicenseArn`.
<note markdown=“1”> To successfully resolve the token, the API must be called from the account that was used to publish the SaaS application. For an example of using ‘ResolveCustomer`, see [ ResolveCustomer code example] in the *Amazon Web Services Marketplace Seller Guide*.
</note>
Permission is required for this operation. Your IAM role or user performing this operation requires a policy to allow the ‘aws-marketplace:ResolveCustomer` action. For more information, see [Actions, resources, and condition keys for Amazon Web Services Marketplace Metering Service] in the *Service Authorization Reference*.
For Amazon Web Services Regions that support ‘ResolveCustomer`, see [ResolveCustomer Region support].
[1]: docs.aws.amazon.com/marketplace/latest/userguide/saas-code-examples.html#saas-resolvecustomer-example [2]: docs.aws.amazon.com/service-authorization/latest/reference/list_awsmarketplacemeteringservice.html [3]: docs.aws.amazon.com/marketplace/latest/APIReference/metering-regions.html#resolvecustomer-region-support
922 923 924 925 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 922 def resolve_customer(params = {}, = {}) req = build_request(:resolve_customer, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
951 952 953 |
# File 'lib/aws-sdk-marketplacemetering/client.rb', line 951 def waiter_names [] end |