Class: Aws::MarketplaceMetering::Types::DuplicateRequestException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacemetering/types.rb

Overview

A metering record has already been emitted by the same EC2 instance, ECS task, or EKS pod for the given timestamp with a different usageQuantity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


110
111
112
113
114
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 110

class DuplicateRequestException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end