Class: Aws::MarketplaceMetering::Types::ExpiredTokenException
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceMetering::Types::ExpiredTokenException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacemetering/types.rb
Overview
The submitted registration token has expired. This can happen if the buyer's browser takes too long to redirect to your page, the buyer has resubmitted the registration token, or your application has held on to the registration token for too long. Your SaaS registration website should redeem this token as soon as it is submitted by the buyer's browser.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
128 129 130 131 132 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 128 class ExpiredTokenException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |