Class: Aws::MarketplaceMetering::Types::InvalidRegionException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacemetering/types.rb

Overview

RegisterUsage must be called in the same Amazon Web Services Region the ECS task was launched in. This prevents a container from hardcoding a Region (e.g. withRegion(“us-east-1”) when calling RegisterUsage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


242
243
244
245
246
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 242

class InvalidRegionException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end