Class: Aws::MarketplaceMetering::Types::MeterUsageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacemetering/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value.

If you don't provide this value, then Amazon Web Services generates a random one for you.

If you retry the operation with the same ClientToken, but with different parameters, the retry fails with an IdempotencyConflictException error.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Checks whether you have the permissions required for the action, but does not make the request. If you have the permissions, the request returns DryRunOperation; otherwise, it returns UnauthorizedException. Defaults to false if not specified.

Returns:

  • (Boolean)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#product_codeString

Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product.

Returns:

  • (String)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

Timestamp, in UTC, for which the usage is being reported. Your application can meter usage for up to six hours in the past. Make sure the timestamp value is not before the start of the software usage.

Returns:

  • (Time)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#usage_allocationsArray<Types::UsageAllocation>

The set of UsageAllocations to submit.

The sum of all UsageAllocation quantities must equal the UsageQuantity of the MeterUsage request, and each UsageAllocation must have a unique set of tags (include no tags).

Returns:



363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#usage_dimensionString

It will be one of the fcp dimension name provided during the publishing of the product.

Returns:

  • (String)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#usage_quantityInteger

Consumption value for the hour. Defaults to 0 if not specified.

Returns:

  • (Integer)


363
364
365
366
367
368
369
370
371
372
373
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363

class MeterUsageRequest < Struct.new(
  :product_code,
  :timestamp,
  :usage_dimension,
  :usage_quantity,
  :dry_run,
  :usage_allocations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end