Class: Aws::MarketplaceMetering::Types::TimestampOutOfBoundsException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplacemetering/types.rb

Overview

The timestamp value passed in the UsageRecord is out of allowed range.

For BatchMeterUsage, if any of the records are outside of the allowed range, the entire batch is not processed. You must remove invalid records and try again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


565
566
567
568
569
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 565

class TimestampOutOfBoundsException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end