Class: Aws::MarketplaceMetering::Types::BatchMeterUsageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceMetering::Types::BatchMeterUsageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacemetering/types.rb
Overview
A BatchMeterUsageRequest contains UsageRecords, which indicate
quantities of usage within your application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#product_code ⇒ String
Product code is used to uniquely identify a product in Amazon Web Services Marketplace.
-
#usage_records ⇒ Array<Types::UsageRecord>
The set of
UsageRecordsto submit.
Instance Attribute Details
#product_code ⇒ String
Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product.
ProductCode is required only for legacy integrations that use
CustomerIdentifier. For new integrations using LicenseArn
(Concurrent Agreements), do NOT include ProductCode at the request
level. The LicenseArn in each UsageRecord identifies both the
product and the specific agreement.
Sending metering records with both ProductCode and LicenseArn
for the same customer within the same hour will result in duplicate
billing. If you are migrating from product-based metering to
license-based metering, stop sending ProductCode before you start
sending LicenseArn.
41 42 43 44 45 46 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 41 class BatchMeterUsageRequest < Struct.new( :usage_records, :product_code) SENSITIVE = [] include Aws::Structure end |
#usage_records ⇒ Array<Types::UsageRecord>
The set of UsageRecords to submit. BatchMeterUsage accepts up to
25 UsageRecords at a time.
41 42 43 44 45 46 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 41 class BatchMeterUsageRequest < Struct.new( :usage_records, :product_code) SENSITIVE = [] include Aws::Structure end |