Class: Aws::MarketplaceMetering::Types::MeterUsageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceMetering::Types::MeterUsageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacemetering/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#dry_run ⇒ Boolean
Checks whether you have the permissions required for the action, but does not make the request.
-
#product_code ⇒ String
Product code is used to uniquely identify a product in Amazon Web Services Marketplace.
-
#timestamp ⇒ Time
Timestamp, in UTC, for which the usage is being reported.
-
#usage_allocations ⇒ Array<Types::UsageAllocation>
The set of
UsageAllocationsto submit. -
#usage_dimension ⇒ String
It will be one of the fcp dimension name provided during the publishing of the product.
-
#usage_quantity ⇒ Integer
Consumption value for the hour.
Instance Attribute Details
#client_token ⇒ String
Specifies a unique, case-sensitive identifier that you provide to ensure the idempotency of the request. This lets you safely retry the request without accidentally performing the same operation a second time. Passing the same value to a later call to an operation requires that you also pass the same value for all other parameters. We recommend that you use a UUID type of value.
If you don't provide this value, then Amazon Web Services generates a random one for you.
If you retry the operation with the same ClientToken, but with
different parameters, the retry fails with an
IdempotencyConflictException error.
A suitable default value is auto-generated. You should normally not need to pass this option.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks whether you have the permissions required for the action, but
does not make the request. If you have the permissions, the request
returns DryRunOperation; otherwise, it returns
UnauthorizedException. Defaults to false if not specified.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#product_code ⇒ String
Product code is used to uniquely identify a product in Amazon Web Services Marketplace. The product code should be the same as the one used during the publishing of a new product.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
Timestamp, in UTC, for which the usage is being reported. Your
application can meter usage for up to six hours in the past. Make
sure the timestamp value is not before the start of the software
usage.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#usage_allocations ⇒ Array<Types::UsageAllocation>
The set of UsageAllocations to submit.
The sum of all UsageAllocation quantities must equal the
UsageQuantity of the MeterUsage request, and each
UsageAllocation must have a unique set of tags (include no tags).
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#usage_dimension ⇒ String
It will be one of the fcp dimension name provided during the publishing of the product.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |
#usage_quantity ⇒ Integer
Consumption value for the hour. Defaults to 0 if not specified.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 363 class MeterUsageRequest < Struct.new( :product_code, :timestamp, :usage_dimension, :usage_quantity, :dry_run, :usage_allocations, :client_token) SENSITIVE = [] include Aws::Structure end |