Class: Aws::MarketplaceMetering::Types::ResolveCustomerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceMetering::Types::ResolveCustomerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacemetering/types.rb
Overview
Contains input to the ResolveCustomer operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#registration_token ⇒ String
When a buyer visits your website during the registration process, the buyer submits a registration token through the browser.
Instance Attribute Details
#registration_token ⇒ String
When a buyer visits your website during the registration process,
the buyer submits a registration token through the browser. The
registration token is resolved to obtain a CustomerIdentifier
along with the CustomerAWSAccountId, ProductCode, and
LicenseArn.
CustomerIdentifier field is
not populated. Use CustomerAWSAccountId and LicenseArn for
customer identification.
462 463 464 465 466 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 462 class ResolveCustomerRequest < Struct.new( :registration_token) SENSITIVE = [] include Aws::Structure end |