Class: Aws::MarketplaceMetering::Types::ResolveCustomerResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::MarketplaceMetering::Types::ResolveCustomerResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-marketplacemetering/types.rb
Overview
The result of the ResolveCustomer operation. Contains the
CustomerIdentifier along with the CustomerAWSAccountId,
ProductCode, and LicenseArn.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_aws_account_id ⇒ String
The
CustomerAWSAccountIdprovides the Amazon Web Services account ID associated with theCustomerIdentifierfor the individual customer. -
#customer_identifier ⇒ String
The
CustomerIdentifieris used to identify an individual customer in your application. -
#license_arn ⇒ String
The
LicenseArnis a unique identifier for a specific granted license. -
#product_code ⇒ String
The product code is returned to confirm that the buyer is registering for your product.
Instance Attribute Details
#customer_aws_account_id ⇒ String
The CustomerAWSAccountId provides the Amazon Web Services account
ID associated with the CustomerIdentifier for the individual
customer. Calls to BatchMeterUsage require CustomerAWSAccountId
for each UsageRecord.
508 509 510 511 512 513 514 515 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 508 class ResolveCustomerResult < Struct.new( :customer_identifier, :product_code, :customer_aws_account_id, :license_arn) SENSITIVE = [] include Aws::Structure end |
#customer_identifier ⇒ String
The CustomerIdentifier is used to identify an individual customer
in your application.
For new SaaS product integrations, this field is not populated. Use
CustomerAWSAccountId and LicenseArn to identify customers
instead.
508 509 510 511 512 513 514 515 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 508 class ResolveCustomerResult < Struct.new( :customer_identifier, :product_code, :customer_aws_account_id, :license_arn) SENSITIVE = [] include Aws::Structure end |
#license_arn ⇒ String
The LicenseArn is a unique identifier for a specific granted
license. These are typically used for software purchased through
Amazon Web Services Marketplace. Calls to BatchMeterUsage require
LicenseArn for each UsageRecord.
CustomerAWSAccountId and LicenseArn in the
response, store that for future purposes/API calls/integrations.
508 509 510 511 512 513 514 515 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 508 class ResolveCustomerResult < Struct.new( :customer_identifier, :product_code, :customer_aws_account_id, :license_arn) SENSITIVE = [] include Aws::Structure end |
#product_code ⇒ String
The product code is returned to confirm that the buyer is
registering for your product. Subsequent BatchMeterUsage calls
should be made using this product code.
508 509 510 511 512 513 514 515 |
# File 'lib/aws-sdk-marketplacemetering/types.rb', line 508 class ResolveCustomerResult < Struct.new( :customer_identifier, :product_code, :customer_aws_account_id, :license_arn) SENSITIVE = [] include Aws::Structure end |